@@ -14,6 +14,7 @@ from normcap import __version__, utils
 from normcap.args import create_argparser
 from normcap.logger import logger
 from normcap.models import Config
+from normcap.utils import get_config_directory
 from normcap.window_main import WindowMain
 
 
@@ -29,9 +30,14 @@ def main():
     if args["very_verbose"]:
         logger.setLevel("DEBUG")
 
+    if args["languages"]:
+        args["languages"] = tuple(args["languages"].split("+"))
+
+    args["notifications"] = not args.pop("no_notifications")
+
     logger.info(f"Starting Normcap v{__version__}")
+    logger.debug(f"CLI command: {' '.join(sys.argv)}")
 
-    # QtCore.QCoreApplication.addLibraryPath()
     lib_paths = QtCore.QCoreApplication.libraryPaths()
     logger.debug(f"QT LibraryPaths: {lib_paths}")
 
@@ -47,7 +53,18 @@ def main():
         system_info = utils.get_system_info()
         logger.debug(f"Detected system info:{system_info}")
 
-        config = Config(**args)
+        # Init configuration
+        config_file = get_config_directory() / "normcap" / "config.yaml"
+        config = Config(file_path=config_file)
+
+        # Overwrite config from cli (if applicable)
+        for key, value in args.items():
+            if (value != arg_parser.get_default(key)) and (
+                key in config.__dataclass_fields__
+            ):
+                logger.debug(f"Override configuration form CLI: {key}: {value}")
+                config.__setattr__(key, value)
+
         logger.debug(f"Applied user config:{config}")
 
         window = WindowMain(config, system_info)
