@@ -4,8 +4,10 @@ import os
 import pprint
 import statistics
 from dataclasses import dataclass, field
+from pathlib import Path
 from typing import Dict, List, Optional, Tuple
 
+import yaml
 from PySide2 import QtGui
 
 FILE_ISSUE_TEXT = (
@@ -135,23 +137,93 @@ class SystemInfo:
         return string
 
 
-@dataclass()
-class Config:
+@dataclass
+class ConfigBase:
     """User settings (set via CLI args)."""
 
-    color: str
-    language: str
-    no_notifications: bool
-    tray: bool
-    verbose: bool
-    very_verbose: bool
+    color: str = "#FF2E88"
+    # TODO: Get's not initialized correctly.
+    languages: Tuple[str] = ("eng",)
+    mode: str = "parse"
+    notifications: bool = True
+    tray: bool = False
+    updates: bool = False
 
     def __repr__(self):
-        string = pprint.pformat(self.__dict__, indent=3)
+        fields = self.__dataclass_fields__  # pylint: disable=no-member
+        data = {k: getattr(self, k) for k in fields}
+        string = pprint.pformat(data, indent=3)
         string = _format_section(string, "Config")
         return string
 
 
+# pylint: disable=no-member # doesn't work with dataclasses
+
+
+class Config(ConfigBase):
+    """User settings (set via CLI args)."""
+
+    __dataclass_fields__: dict
+    init_complete: bool = False
+
+    def __init__(self, file_path: Path):
+        super().__init__()
+        self.__annotations__ = super().__annotations__
+
+        self.file_path = file_path
+        self._load_from_file()
+        self.init_complete = True
+
+    def __setattr__(self, name, value):
+        if (name in self.__dataclass_fields__) and (getattr(self, name) == value):
+            return
+
+        super().__setattr__(name, value)
+
+        if name == "file_path" or not self.init_complete:
+            return
+
+        self._save_to_file()
+
+    def _save_to_file(self):
+        """Save dataclass as yaml."""
+        if self.file_path.is_dir():
+            raise ValueError(
+                f"{self.file_path.absolute()} is an exisiting directory, not a file."
+            )
+
+        self.file_path.parent.mkdir(parents=True, exist_ok=True)
+
+        with open(self.file_path, "w") as f:
+            data = {}
+            for k in super().__annotations__:
+                value = getattr(self, k)
+                if isinstance(value, tuple):
+                    value = list(value)
+                data[k] = value
+            yaml.dump(data, f, allow_unicode=True)
+
+    def _load_from_file(self):
+        """Load dataclass from yaml."""
+        if not self.file_path.is_file():
+            return
+
+        with open(self.file_path, "r") as f:
+            config = yaml.load(f, Loader=yaml.FullLoader)
+
+        if not config:
+            return
+
+        for key, value in config.items():
+            if key in super().__annotations__:
+                if isinstance(value, list):
+                    value = tuple(value)
+                setattr(self, key, value)
+
+
+# pylint: enable=no-member
+
+
 @dataclass()
 class Capture:
     """Store all information about selected region."""
