@@ -7,12 +7,12 @@ import os
 import sys
 import tempfile
 from pathlib import Path
-from typing import Dict, List
+from typing import Dict, List, Optional
 
 import importlib_metadata
 import importlib_resources
 import tesserocr  # type: ignore  # pylint: disable=wrong-import-order
-from jeepney.integrate.blocking import connect_and_authenticate  # type: ignore
+from jeepney.io.blocking import open_dbus_connection  # type: ignore
 from jeepney.wrappers import MessageGenerator, new_method_call  # type: ignore
 from PySide2 import QtCore, QtGui, QtWidgets
 
@@ -261,7 +261,7 @@ def move_active_window_to_position_on_gnome(screen_geometry):
             """Grab specific section to file with flash disabled."""
             return new_method_call(self, "Eval", "s", (JS_CODE,))
 
-    connection = connect_and_authenticate(bus="SESSION")
+    connection = open_dbus_connection(bus="SESSION")
     msg = MoveWindow().move()
     _ = connection.send_and_get_reply(msg)
 
@@ -293,3 +293,36 @@ def get_config_directory() -> Path:
     if xdg_config_home:
         return Path(xdg_config_home)
     return Path.home() / ".config"
+
+
+def get_icon(icon_file: str, system_icon: Optional[str] = None):
+    """Load icon from system or if not available from resources."""
+    icon = None
+    if system_icon:
+        icon = QtGui.QIcon.fromTheme(system_icon)
+    if not icon:
+        with importlib_resources.path("normcap.resources", icon_file) as fp:
+            icon_path = str(fp.absolute())
+        icon = QtGui.QIcon()
+        icon.addFile(icon_path)
+    return icon
+
+
+def set_cursor(cursor: Optional[QtCore.Qt.CursorShape] = None):
+    """Show in-progress cursor for application.
+
+    QtCore.Qt.WaitCursor
+    QtCore.Qt.CrossCursor
+    QtCore.Qt.ArrowCursor
+    """
+    if cursor is not None:
+        QtWidgets.QApplication.setOverrideCursor(cursor)
+    else:
+        QtWidgets.QApplication.restoreOverrideCursor()
+    QtWidgets.QApplication.processEvents()
+
+
+def open_url_and_hide(window, url):
+    """Open url and quit or hide NormCap."""
+    QtGui.QDesktopServices.openUrl(url)
+    window.com.onQuitOrHide.emit()
